import type { ColDef, ICellRendererComp, ICellRendererParams } from '@ag-grid-community/core';
import { ActionMenuItem } from '@genesislcap/foundation-ui';
import { FoundationElement } from '@microsoft/fast-foundation';
/**
 * The Actions Menu Renderer element.
 * @remarks For multiple actions scenarios.
 * @public
 * @tagname %%prefix%%-grid-pro-actions-menu-renderer
 */
export declare class ActionsMenuRenderer extends FoundationElement implements ICellRendererComp {
    params: ICellRendererParams;
    init(params: ICellRendererParams): void;
    getGui(): HTMLElement;
    refresh(params: ICellRendererParams): boolean;
}
/**
 * A function that returns a Foundation Actions Menu for configuring the component with a DesignSystem.
 *
 * @public
 * @remarks
 * HTML Element: \<foundation-grid-pro-actions-menu-renderer\>
 */
export declare const foundationGridProActionsMenuRenderer: (overrideDefinition?: import("@microsoft/fast-foundation").OverrideFoundationElementDefinition<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}>) => import("@microsoft/fast-foundation").FoundationElementRegistry<{
    baseName: string;
    template: import("@microsoft/fast-element").ViewTemplate<any, any>;
}, typeof ActionsMenuRenderer>;
/**
 * Helper function to get ColDef {@link https://www.ag-grid.com/javascript-data-grid/column-properties/} for Actions Menu Renderer.
 * Will take the parameter values for a base ColDef and merge them with the overrideDef (if specified).
 * @param actions - Array of {@link @genesislcap/foundation-ui#ActionMenuItem} to be displayed in the menu.
 * @param overrideDef - Optional override for the ColDef. Will override any of the default values. Default is an empty object.
 * @param customActionsOpenerName - Optional custom name for the button that opens the menu. Default is '⋮'.
 * @param isVertical - Optional flag to display the menu vertically. Default is false (displays the menu horizontally, follow the rowHeight).
 * @param buttonAppearance - Optional appearance for the button that opens the menu. Default is 'outline'.
 * @returns Merged ColDef (base ColDef created from the parameters + overrideDef) for Actions Menu Renderer.
 * @example
 * ```ts
 * public exampleActionsMenuDef: ColDef = getActionsMenuDef(
 *  [
 *    {
 *      name: 'View',
 *      callback: (rowData) => logger.debug('VIEWW!!!', rowData),
 *    },
 *      {
 *      name: 'Delete',
 *      callback: (rowData) => logger.debug('DELETE!!!', rowData),
 *    },
 *  ],
 *  {
 *    headerName: 'Instrument Actions',
 *    width: 180,
 *  },
 *  '+',
 *  true,
 *  'primary-gradient'
 * );
 * ```
 * @public
 */
export declare const getActionsMenuDef: (actions: ActionMenuItem[], overrideDef?: ColDef, customActionsOpenerName?: string, isVertical?: boolean, buttonAppearance?: string) => ColDef;
//# sourceMappingURL=actions-menu.renderer.d.ts.map